@@ -68,7 +68,7 @@ __END__
 
 =head1 NAME
 
-Lab::XPRESS::Sweep::Repeater - Simple repeater
+Lab::XPRESS::Sweep::Repeater - Simple repeater (deprecated)
 
 =head1 VERSION
 
@@ -88,6 +88,8 @@ version 3.899
 
 =head1 DESCRIPTION
 
+This module belongs to a deprecated legacy module stack, frozen and not under development anymore. Please port your code to the new API; its documentation can be found on the Lab::Measurement homepage, L<https://www.labmeasurement.de/>.
+
 Parent: Lab::XPRESS::Sweep
 
 The Lab::XPRESS::Sweep::Repeater class implements a simple repeater module in the Lab::XPRESS::Sweep framework.
