@@ -405,7 +405,7 @@ __END__
 
 =head1 NAME
 
-Lab::XPRESS::Sweep::Temperature - Temperature sweep
+Lab::XPRESS::Sweep::Temperature - Temperature sweep (deprecated)
 
 =head1 VERSION
 
@@ -434,6 +434,8 @@ version 3.899
 
 =head1 DESCRIPTION
 
+This module belongs to a deprecated legacy module stack, frozen and not under development anymore. Please port your code to the new API; its documentation can be found on the Lab::Measurement homepage, L<https://www.labmeasurement.de/>.
+
 Parent: Lab::XPRESS::Sweep
 
 The Lab::XPRESS::Sweep::Temperature class implements a module for temperature sweeps in the Lab::XPRESS::Sweep framework.
